//    Copyright 2013 Anna Bassi, EnginSoft S.P.A.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.




// Using floating point exception produces Inf or Nan
ieee(2)
// close all 
xdel(winsid()) 


// Import functions
pathdir = get_absolute_file_path('data_mining.sce');
getd(pathdir + 'functions');


// Loading data
S = csvRead('data_UN.csv',',','.', 'string');
D = csvRead('data_UN.csv');
data = D(2:$,:);



// History plot
// Getting rid of the NaN entries
[gdp,k] = thrownan(data(:,23)); 
[rationonan,kk] = thrownan(data(k,14)); 
gdpnonan = gdp(kk);
// Plot
[p,i] = gsort(gdpnonan,'g','i');
//table = [S(1,2) S(1,23) S(1,14);
//        S(k(kk(i))+1,2) S(k(kk(i))+1,23) S(k(kk(i))+1,14)];
//disp(table)
scf(1); clf(1);
plot([1:30],rationonan(i(1:30)),'bo-')
plot([1:30],data(k(kk(i(1:30))),15),'go-')
[m,im] = min(rationonan(i(1:30)));
plot([0,im],[m,m],'r')
[M,iM] = max(rationonan(i(1:30)));
plot([0,iM],[M,M],'r')
set(gca(),"grid",[1 1]*color('gray')); 
set(gca(),"data_bounds",[0 30 0 1200]);
//title('Maternal mortality ratio in the poor states');
title('Maternal and infant mortality ratio in the poor states');
// Data normalization
dnorm = [rationonan(i(1:30)),data(k(kk(i(1:30))),15)];
for i = 1:size(dnorm,2)
    dmin(i) = min(dnorm(:,i));
    dmax(i) = max(dnorm(:,i));
    dnorm(:,i) = (dnorm(:,i)-dmin(i)) ./ (dmax(i)-dmin(i));
end
// Plot
scf(2); clf(2);
plot([1:30],dnorm(:,1),'bo-')
plot([1:30],dnorm(:,2),'go-')
set(gca(),"grid",[1 1]*color('gray')); 
set(gca(),"data_bounds",[0 30 0 1]);



// Sorting the population size and plotting the Pie Chart
[p,ind] = gsort(data(:,5));
scf(3); clf(3);
pie([p(1:10);sum(p(11:$))])
legend([S(ind(1:10)+1,2);"Rest of the world"]); 



// Bar Chart and cumulative
[gdpnonan,i] = thrownan(data(:,23));
[gdp,j] = gsort(gdpnonan);
tot_gdp = sum(gdp);
cum_gdp = cumsum(gdp(1:10));
scf(4); clf(4);
bar(gdp(1:10)*100/tot_gdp)
plot([1:10],cum_gdp*100/tot_gdp,'ro-')
set(gca(),"grid",[1 1]*color('gray')); 
h = get("current_entity");
h.parent.x_ticks.labels = S(i(j(1:10))+1,1);
h.parent.y_ticks.labels = h.parent.y_ticks.labels+'%';



// Barhomogenized
[fif,k] = thrownan(data(:,10));
sixw = data(k,12);
[sixm,i] = thrownan(data(k,11));
fif  = fif(i);
[sixw,j] = thrownan(sixw(i));
fif = fif(j);
sixm = sixm(j);
scf(5); clf(5);
// Stacked Barhomogenize
subplot(1,2,1)
x = 1:10;
bar(x,sixm(1:10),'blue');
bar(x,sixw(1:10),'red');
bar(x,fif(1:10),'yellow');
barhomogenize('stacked',1);
h = get("current_entity");
h.parent.x_ticks.labels = S(k(i(j(1:10)))+1,1);
h.parent.y_ticks.labels = h.parent.y_ticks.labels+'%';
// Standard Barhomogenize
subplot(1,2,2)
bar(x,sixm(1:10),'blue');
bar(x,sixw(1:10),'red');
bar(x,fif(1:10),'yellow');
barhomogenize();
h = get("current_entity");
h.parent.x_ticks.labels = S(k(i(j(1:10)))+1,1);
h.parent.y_ticks.labels = h.parent.y_ticks.labels+'%';



// Bubblechart 
scf(6); clf(6);
[d,ind] = gsort(data(:,5));
Lat = data(ind,3);
Lon = data(ind,4);
x = Lat.*%pi ./180;
y = Lon.*%pi ./180;
X = y*60*1852 .*cos(x); // X = longitude*60*1852*cos(latitude)
Y = x.*60*1852; //Y = latitude*60*1852
Z = data(ind,5);
m = size(data,"r");
// A: the area covered by the (X,Y) data
maxR = 50000;
A = (max(Y)-min(Y))/(max(X)-min(X));
// The area, pi*R(i)^2, is proportionnal to Z(i)
R = sqrt(Z/%pi);
R = R/max(R);
R = sqrt(A)*maxR*R;
a = R;
b = 1*R; 
bounds = [%inf %inf
          -%inf -%inf];
for i = 1:m    
    k = 100;
    t = 2*%pi*(0:k-1)/k;
    xv = X(i)+a(i)*sin(t);
    yv = Y(i)+b(i)*cos(t);
    if i <= 10 then
        xfpoly(xv,yv,5);
    else
        xfpoly(xv,yv,3);
    end
    ibounds = [min(xv) min(yv)
               max(xv) max(yv)];
    bounds(1,1)=min(bounds(1,1),ibounds(1,1));
    bounds(2,1)=max(bounds(2,1),ibounds(2,1));
    bounds(1,2)=min(bounds(1,2),ibounds(1,2));
    bounds(2,2)=max(bounds(2,2),ibounds(2,2));
end
plot(mean(X),mean(Y))
// Get dynamic axes
h = gcf();
h.children.data_bounds = bounds;
datatipRedraw()



// Histograms
LEW = thrownan(data(:,16));
LEM = thrownan(data(:,17));
classes = 45:5:90; 
lW = length(LEW); 
lM = length(LEM);
scf(7); clf(7);
subplot(2,1,1)
histplot(classes, LEW, normalization=%f, style=5)
h = get("current_entity");
xtitle("Life expectancy at birth: Women");
subplot(2,1,2)
histplot(classes, LEM, normalization=%f, style=2)
h = get("current_entity");
xtitle("Life expectancy at birth: Men");



// Box-and-whisker
scf(8); clf(8);
subplot(1,2,1)
[outUp, outDown] = box_whiskers(LEW)
a = get("current_axes");
a.data_bounds = [0,45;2,90]; 
xtitle("Life expectancy at birth: Women");
subplot(1,2,2)
[outUp, outDown] = box_whiskers(LEM)
a = get("current_axes");
a.data_bounds = [0,45;2,90]; 
xtitle('Life expectancy at birth: Men')



// Parallel coordinates
[i1,j1] = find(S=='US'); // United States
[i2,j2] = find(S=='CN'); // China
[i3,j3] = find(S=='AF'); // Afghanistan
plot_parallel_chart(9,data(:,5:15),i1-1,S(1,5:15))
plot_parallel_chart(10,data(:,5:15),[i1-1,i2-1,i3-1],S(1,5:15))



//Plot the linear correlation coefficient matrix
data_lin_corr = data(:,3:$);
linear_corr_matrix(11,data_lin_corr,S(1,3:$))



//Reglin
[im,k] = thrownan(data(:,15)); // infant mortality
[slew_nonan,kk] = thrownan(data(k,22)); // school life expectancy women
im_nonan = im(kk);
[a,b] = reglin(im_nonan',slew_nonan');
scf(12); clf(12);
x = linspace(0,max(im),3);
plot(x,(a*x+b) ,'-r')
plot(im_nonan,slew_nonan,'*')
xlabel('Annual infants dying before reaching the age of one year per 1000 live births');
ylabel('School life expectancy for women (in years)');
