//    Copyright 2013 Massimiliano Margonari, Anna Bassi, EnginSoft S.P.A.
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.




function [] = linear_corr_matrix(fig_id,data,labels)
//Plot the linear correlation coefficient matrix
//data [np,nv]
//np = number of points
//nv = number of variables

[np,nv] = size(data);
px=[ 0.5 0.5 -0.5 -0.5]';
py=[-0.5 0.5  0.5 -0.5]';

coeff_matrix=zeros(nv,nv);

postx=zeros(1,nv*nv);
posty=zeros(1,nv*nv);
posx=zeros(4,nv*nv);
posy=zeros(4,nv*nv);
col=zeros(1,nv*nv);
icount=0;
for i=1:nv
 for j=1:nv
  icount=icount+1;
  [di,k] = thrownan(data(:,i));
  [dj_nonan,kk] = thrownan(data(k,j));
  di_nonan = di(kk);
  coeff_matrix(i,j)=linear_correlation(di_nonan,dj_nonan);
  // position of the coefficient in the tabel
  postx(1,icount)=i;
  posty(1,icount)=nv+1-j;
  // 4 corners of every 1x1 cell
  posx(:,icount)=i+px;
  posy(:,icount)=(nv+1-j)+py;
  // color
  col(1,icount)=round((32-1)/(1-(-1))*(coeff_matrix(i,j)-(-1))+1);
 end
end
f = scf(fig_id);
xtitle("Linear Correlation Coefficient");
f.color_map=jetcolormap(32);
plot2d(0,0,rect=[0,0,nv+1,nv+1],axesflag=0);
// main diagonal = white
for c = 0:nv-1
col(c*nv+c+1)=0;
end
xfpolys(posx,posy,col);
format("v",5);
prova=matrix(string(coeff_matrix),1,nv*nv)
for c = 0:nv-1
prova(c*nv+c+1)=' ';
end
// draw strings in given positions in the plot
xstring(postx-0.2,posty-0.2,prova);
postLabX = .5:1:nv-.5;
postLabY = nv-.5:-1:.5;
xstring(postLabX,postLabY+.2,labels);
format(10);
endfunction
